==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/BoxesType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BoxesType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BoxesType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="mediaBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType"/&gt;
 *         &lt;element name="cropBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="bleedBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="trimBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="artBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BoxesType", propOrder = {
    "mediaBox",
    "cropBox",
    "bleedBox",
    "trimBox",
    "artBox"
})
public class BoxesType {

    @XmlElement(required = true)
    protected RectangleType mediaBox;
    protected RectangleType cropBox;
    protected RectangleType bleedBox;
    protected RectangleType trimBox;
    protected RectangleType artBox;

    /**
     * Gets the value of the mediaBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getMediaBox() {
        return mediaBox;
    }

    /**
     * Sets the value of the mediaBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setMediaBox(RectangleType value) {
        this.mediaBox = value;
    }

    public boolean isSetMediaBox() {
        return (this.mediaBox!= null);
    }

    /**
     * Gets the value of the cropBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getCropBox() {
        return cropBox;
    }

    /**
     * Sets the value of the cropBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setCropBox(RectangleType value) {
        this.cropBox = value;
    }

    public boolean isSetCropBox() {
        return (this.cropBox!= null);
    }

    /**
     * Gets the value of the bleedBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getBleedBox() {
        return bleedBox;
    }

    /**
     * Sets the value of the bleedBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setBleedBox(RectangleType value) {
        this.bleedBox = value;
    }

    public boolean isSetBleedBox() {
        return (this.bleedBox!= null);
    }

    /**
     * Gets the value of the trimBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getTrimBox() {
        return trimBox;
    }

    /**
     * Sets the value of the trimBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setTrimBox(RectangleType value) {
        this.trimBox = value;
    }

    public boolean isSetTrimBox() {
        return (this.trimBox!= null);
    }

    /**
     * Gets the value of the artBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getArtBox() {
        return artBox;
    }

    /**
     * Sets the value of the artBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setArtBox(RectangleType value) {
        this.artBox = value;
    }

    public boolean isSetArtBox() {
        return (this.artBox!= null);
    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/extraction/info/BoxesType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;


/**
 * <p>Java class for BoxesType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BoxesType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="mediaBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType"/&gt;
 *         &lt;element name="cropBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="bleedBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="trimBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *         &lt;element name="artBox" type="{http://schema.webpdf.de/1.0/extraction/info}RectangleType" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BoxesType", propOrder = {
    "mediaBox",
    "cropBox",
    "bleedBox",
    "trimBox",
    "artBox"
})
@JsonIgnoreProperties(ignoreUnknown = true)
public class BoxesType {

    @XmlElement(required = true)
    protected RectangleType mediaBox;
    protected RectangleType cropBox;
    protected RectangleType bleedBox;
    protected RectangleType trimBox;
    protected RectangleType artBox;

    /**
     * Gets the value of the mediaBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getMediaBox() {
        return mediaBox;
    }

    /**
     * Sets the value of the mediaBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setMediaBox(RectangleType value) {
        this.mediaBox = value;
    }

    public boolean isSetMediaBox() {
        return (this.mediaBox!= null);
    }

    /**
     * Gets the value of the cropBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getCropBox() {
        return cropBox;
    }

    /**
     * Sets the value of the cropBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setCropBox(RectangleType value) {
        this.cropBox = value;
    }

    public boolean isSetCropBox() {
        return (this.cropBox!= null);
    }

    /**
     * Gets the value of the bleedBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getBleedBox() {
        return bleedBox;
    }

    /**
     * Sets the value of the bleedBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setBleedBox(RectangleType value) {
        this.bleedBox = value;
    }

    public boolean isSetBleedBox() {
        return (this.bleedBox!= null);
    }

    /**
     * Gets the value of the trimBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getTrimBox() {
        return trimBox;
    }

    /**
     * Sets the value of the trimBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setTrimBox(RectangleType value) {
        this.trimBox = value;
    }

    public boolean isSetTrimBox() {
        return (this.trimBox!= null);
    }

    /**
     * Gets the value of the artBox property.
     * 
     * @return
     *     possible object is
     *     {@link RectangleType }
     *     
     */
    public RectangleType getArtBox() {
        return artBox;
    }

    /**
     * Sets the value of the artBox property.
     * 
     * @param value
     *     allowed object is
     *     {@link RectangleType }
     *     
     */
    public void setArtBox(RectangleType value) {
        this.artBox = value;
    }

    public boolean isSetArtBox() {
        return (this.artBox!= null);
    }

}
